
DNA Features Viewer
===================

DNA Features Viewer is a Python library to visualize DNA features, e.g. from GenBank or Gff files:

.. figure:: https://raw.githubusercontent.com/Edinburgh-Genome-Foundry/DnaFeaturesViewer/master/examples/translator_with_custom_colors.png
    :width: 500px
    :align: center
    :alt: some figure

Dna Features Viewer can plot sequence maps linearly or circularly, with or without nucleotide sequence and amino-acid sequences. The plotter automatically produces clear plots even for sequences with many overlapping features and long labels. The library plays well with Matplotlib and Biopython, and the figures can be saved in different formats (PNG, JPEG, SVG, PDF), e.g. for report generation or LIMS interfaces.

Infos
-----

**PIP installation:**

.. code:: bash

  pip install dna_features_viewer

**Web documentation:**

`<https://edinburgh-genome-foundry.github.io/DnaFeaturesViewer/>`_

**Github Page**

`<https://github.com/Edinburgh-Genome-Foundry/DnaFeaturesViewer>`_

**Live demo**

`<http://cuba.genomefoundry.org/plot-sequence-features>`_

**License:** MIT, Copyright Edinburgh Genome Foundry

More biology software
-----------------------

.. image:: https://raw.githubusercontent.com/Edinburgh-Genome-Foundry/Edinburgh-Genome-Foundry.github.io/master/static/imgs/logos/egf-codon-horizontal.png
  :target: https://edinburgh-genome-foundry.github.io/

Dna Features Viewer is part of the `EGF Codons <https://edinburgh-genome-foundry.github.io/>`_ synthetic biology software suite for DNA design, manufacturing and validation.
